pub trait TokenProvider:
Send
+ Sync
+ Debug {
// Required method
fn token<'life0, 'async_trait>(
&'life0 self,
) -> Pin<Box<dyn Future<Output = Result<AuthToken, SdkError>> + Send + 'async_trait>>
where 'life0: 'async_trait,
Self: 'async_trait;
}Expand description
Produces the Authorization header for every outgoing SDK request.
Required Methods
Sourcefn token<'life0, 'async_trait>(
&'life0 self,
) -> Pin<Box<dyn Future<Output = Result<AuthToken, SdkError>> + Send + 'async_trait>>where
'life0: 'async_trait,
Self: 'async_trait,
fn token<'life0, 'async_trait>(
&'life0 self,
) -> Pin<Box<dyn Future<Output = Result<AuthToken, SdkError>> + Send + 'async_trait>>where
'life0: 'async_trait,
Self: 'async_trait,
Return the credentials to attach to the next request. May be called on the hot path, so implementations should cache aggressively.