pub struct ApiKey { /* private fields */ }Expand description
A parsed OpenApp API-key token.
Implementations
Sourceimpl ApiKey
impl ApiKey
Sourcepub fn parse(token: impl Into<String>) -> Result<ApiKey, TokenFormatError>
pub fn parse(token: impl Into<String>) -> Result<ApiKey, TokenFormatError>
Parse a token string of the form {origin}_openapp_{secret}.
Errors
Returns a TokenFormatError if the token is empty, lacks the separator, has an
empty secret, or if origin is not a bare absolute http(s) origin.
Sourcepub fn api_base_url(&self) -> Url
pub fn api_base_url(&self) -> Url
The versioned API root requests are resolved against: {origin}/api/v1.